# tiqs
This code is developed to mitigate the problem of exponential growth of Liouvillian spaces in Open Quantum Systems on extended lattices.
To do so, one exploits the symmetries of such systems.
The `qutip` package is its main dependency. [qutip.org](http://qutip.org)

In development.
